@@ -1,124 +1,139 @@
-""" :inventory """
-import curses
+"""Inventory subcommand implementation."""
 import glob
 import json
 import os
 import shlex
 import shutil
 
+from pathlib import Path
 from typing import Any
 from typing import Dict
 from typing import List
+from typing import Optional
 from typing import Tuple
 from typing import Union
 
-from . import run_action
-from . import _actions as actions
-
-from ..app import App
+from ansible_navigator.content_defs import ContentFormat
+from ..action_base import ActionBase
+from ..action_defs import RunStdoutReturn
 from ..app_public import AppPublic
 from ..configuration_subsystem import ApplicationConfiguration
-from ..runner.api import CommandRunner, InventoryRunner
+from ..runner import AnsibleInventory
+from ..runner import Command
 from ..steps import Step
+from ..ui_framework import Color
+from ..ui_framework import CursesLine
 from ..ui_framework import CursesLinePart
 from ..ui_framework import CursesLines
+from ..ui_framework import Decoration
 from ..ui_framework import Interaction
-from ..ui_framework import dict_to_form
 from ..ui_framework import warning_notification
+from . import _actions as actions
+from . import run_action
 
 
 def color_menu(colno: int, colname: str, entry: Dict[str, Any]) -> Tuple[int, int]:
-    """Find matching color for word
+    """Provide a color for a inventory menu entry in one column.
 
-    :param colname: A word to match
+    :param colno: The column number
+    :param colname: The column name
+    :param entry: The menu entry
+    :returns: The color and decoration
     """
     if colname in ["__name", "title", "inventory_hostname"]:
-        return 10, 0
+        return Color.BRIGHT_GREEN, Decoration.NORMAL
     if colname == "__taxonomy":
-        return 11, 0
+        return Color.BRIGHT_YELLOW, Decoration.NORMAL
     if colname == "description":
-        return 12, 0
+        return Color.BRIGHT_BLUE, Decoration.NORMAL
     if colname == "__type":
         if entry["__type"] == "group":
-            return 11, 0
-        return 12, 0
-    colors = [14, 13, 6, 5, 4, 3, 2]
-    return colors[colno % len(colors)], 0
+            return Color.BRIGHT_YELLOW, Decoration.NORMAL
+        return Color.BRIGHT_BLUE, Decoration.NORMAL
+    colors = [
+        Color.BRIGHT_CYAN,
+        Color.BRIGHT_MAGENTA,
+        Color.CYAN,
+        Color.MAGENTA,
+        Color.BLUE,
+        Color.YELLOW,
+        Color.GREEN,
+    ]
+    return colors[colno % len(colors)], Decoration.NORMAL
 
 
-def content_heading(obj: Any, screen_w: int) -> Union[CursesLines, None]:
-    """create a heading for host showing
+def content_heading(obj: Any, screen_w: int) -> Optional[CursesLines]:
+    """Create a heading for inventory content.
 
     :param obj: The content going to be shown
-    :type obj: Any
     :param screen_w: The current screen width
-    :type screen_w: int
-    :return: The heading
-    :rtype: Union[CursesLines, None]
+    :returns: The heading
     """
-
-    heading = []
-    string = "[{host}] {os}".format(
-        host=obj["inventory_hostname"],
-        os=obj.get("ansible_network_os", obj.get("ansible_platform", "")),
-    )
+    host = obj["inventory_hostname"]
+    operating_system = obj.get("ansible_network_os", obj.get("ansible_platform", ""))
+    string = f"[{host}] {operating_system}"
     string = string + (" " * (screen_w - len(string) + 1))
-    heading.append(
-        tuple(
-            [
-                CursesLinePart(
-                    column=0,
-                    string=string,
-                    color=0,
-                    decoration=curses.A_UNDERLINE,
-                )
-            ]
-        )
+    line_part = CursesLinePart(
+        column=0,
+        string=string,
+        color=Color.BLACK,
+        decoration=Decoration.UNDERLINE,
     )
-    return tuple(heading)
+    return CursesLines((CursesLine((line_part,)),))
 
 
 def filter_content_keys(obj: Dict[Any, Any]) -> Dict[Any, Any]:
-    """when showing content, filter out some keys"""
+    """Filter out some keys when showing inventory content.
+
+    :param obj: The object from which keys should be removed
+    :returns: The object with keys removed
+    """
     return {k: v for k, v in obj.items() if not k.startswith("__")}
 
 
 class MenuEntry(dict):
-    """a menu entry"""
+    """A menu entry."""
 
 
 class Menu(list):
-    """a menu"""
+    """A menu."""
 
 
 @actions.register
-class Action(App):
-    """:inventory"""
+class Action(ActionBase):
+    """Inventory subcommand implementation."""
 
-    # pylint:disable=too-few-public-methods
     # pylint: disable=too-many-instance-attributes
 
     KEGEX = r"^i(?:nventory)?(\s(?P<params>.*))?$"
 
     def __init__(self, args: ApplicationConfiguration):
+        """Initialize the ``:images`` action.
+
+        :param args: The current settings for the application
+        """
         super().__init__(args=args, logger_name=__name__, name="inventory")
 
         self.__inventory: Dict[Any, Any] = {}
         self._host_vars: Dict[str, Dict[Any, Any]]
-        self._inventories_mtime: Union[float, None]
+        self._inventories_mtime: Optional[float]
         self._inventories: List[str] = []
         self._inventory_error: str = ""
-        self._runner: Union[CommandRunner, InventoryRunner]
+        self._runner: Union[Command, AnsibleInventory]
 
     @property
     def _inventory(self) -> Dict[Any, Any]:
-        """return the inventory"""
+        """Return the inventory.
+
+        :returns: The inventory details
+        """
         return self.__inventory
 
     @_inventory.setter
     def _inventory(self, value: Dict) -> None:
-        """set the inventory
-        and hostvars
+        """Set the inventory and hostvars.
+
+        :param value: The inventory data
         """
         self.__inventory = value
         self._host_vars = {
@@ -133,50 +148,58 @@ class Action(App):
 
     @property
     def _show_columns(self) -> List:
+        """Return the columns to show for an inventory menu.
+
+        :returns: The columns to show
+        """
         if isinstance(self._args.inventory_column, list):
             return self._args.inventory_column
         return []
 
     def _set_inventories_mtime(self) -> None:
-        mtimes = []
+        """Record the inventory modification time."""
+        modification_times = []
         for inventory in self._inventories:
             if os.path.isdir(inventory):
-                mtimes.append(
+                modification_times.append(
                     max(
-                        (
-                            os.path.getmtime(e)
-                            for e in glob.glob(os.path.join(inventory, "**"), recursive=True)
-                        )
-                    )
+                        os.path.getmtime(e)
+                        for e in glob.glob(os.path.join(inventory, "**"), recursive=True)
+                    ),
                 )
             elif os.path.isfile(inventory):
-                mtimes.append(os.path.getmtime(inventory))
-        if mtimes:
-            self._inventories_mtime = max(mtimes)
+                modification_times.append(os.path.getmtime(inventory))
+        if modification_times:
+            self._inventories_mtime = max(modification_times)
         else:
             self._inventories_mtime = None
 
     def update(self):
+        """Request calling app update, inventory update checked in ``run()``."""
         self._calling_app.update()
 
-    def run(self, interaction: Interaction, app: AppPublic) -> Union[Interaction, None]:
-        # pylint: disable=too-many-branches
-        """Handle :inventory
+    def run(self, interaction: Interaction, app: AppPublic) -> Optional[Interaction]:
+        """Execute the ``inventory`` request for mode interactive.
 
         :param interaction: The interaction from the user
-        :type interaction: Interaction
-        :param calling_app: The calling_app instance
-        :type calling_app: App
+        :param app: The app instance
+        :returns: The pending :class:`~ansible_navigator.ui_framework.ui.Interaction` or
+            :data:`None`
         """
         self._logger.debug("inventory requested in interactive mode")
         self._prepare_to_run(app, interaction)
-        self.stdout = self._calling_app.stdout
 
-        self._build_inventory_list()
-        if not self._inventories:
+        args_updated = self._update_args(
+            [self._name] + shlex.split(self._interaction.action.match.groupdict()["params"] or ""),
+        )
+        if not args_updated:
             self._prepare_to_exit(interaction)
             return None
 
+        self.stdout = self._calling_app.stdout
+        self._inventories = self._args.inventory
+        self._set_inventories_mtime()
+
         self._collect_inventory_details()
         if not self._inventory:
             self._prepare_to_exit(interaction)
@@ -184,7 +207,10 @@ class Action(App):
 
         if self._inventory_error:
             while True:
-                interaction = self._interaction.ui.show(self._inventory_error, xform="source.ansi")
+                interaction = self._interaction.ui.show(
+                    self._inventory_error,
+                    content_format=ContentFormat.ANSI,
+                )
                 if interaction.name != "refresh":
                     break
             self._prepare_to_exit(interaction)
@@ -203,9 +229,7 @@ class Action(App):
             if current_mtime != self._inventories_mtime:
                 self._logger.debug("inventory changed")
 
-                self._build_inventory_list()
-                if not self._inventories:
-                    break
+                self._set_inventories_mtime()
 
                 self._collect_inventory_details()
                 if not self._inventory:
@@ -221,16 +245,22 @@ class Action(App):
         self._prepare_to_exit(interaction)
         return None
 
-    def run_stdout(self) -> int:
-        """Run in oldschool mode, just stdout"""
+    def run_stdout(self) -> RunStdoutReturn:
+        """Execute the ``inventory`` request for mode stdout.
+
+        :returns: The return code, 0 or 1. If the runner status if failed, return 1
+            along with a message to review the logs.
+        """
         self._logger.debug("inventory requested in stdout mode")
         if hasattr(self._args, "inventory") and self._args.inventory:
             self._inventories = self._args.inventory
         self._collect_inventory_details()
-        return 1 if self._runner.status == "failed" else 0
+        if self._runner.status == "failed":
+            return RunStdoutReturn(message="Please review the log for errors.", return_code=1)
+        return RunStdoutReturn(message="", return_code=0)
 
     def _take_step(self) -> None:
-
+        """Take a step based on the current step or step back."""
         result = None
         if isinstance(self.steps.current, Interaction):
             result = run_action(self.steps.current.name, self.app, self.steps.current)
@@ -260,24 +290,34 @@ class Action(App):
             self.steps.append(result)
 
     def _build_main_menu(self) -> Step:
+        """Build the inventory menu.
+
+        :returns: The inventory menu definition
+        """
         groups = MenuEntry(
             title="Browse groups",
             description="Explore each inventory group and group members members",
         )
         hosts = MenuEntry(
-            title="Browse hosts", description="Explore the inventory with a list of all hosts"
+            title="Browse hosts",
+            description="Explore the inventory with a list of all hosts",
         )
 
         step = Step(
             name="main_menu",
             columns=["title", "description"],
             select_func=self._step_from_main_menu,
-            tipe="menu",
+            step_type="menu",
             value=[groups, hosts],
         )
         return step
 
     def _step_from_main_menu(self) -> Step:
+        """Take a step away from the main menu.
+
+        :raises IndexError: When the index does not correspond to a menu entry
+        :returns: Either the group or host menu
+        """
         if self.steps.current.index == 0:
             return self._build_group_menu("all")
         if self.steps.current.index == 1:
@@ -285,6 +325,11 @@ class Action(App):
         raise IndexError("broken modules somewhere?")
 
     def _build_group_menu(self, key=None) -> Step:
+        """Build the menu for inventory groups.
+
+        :param key: The optional menu name
+        :returns: The inventory group menu definition
+        """
         if key is None:
             key = self.steps.current.selected["__name"]
 
@@ -293,7 +338,7 @@ class Action(App):
             menu = Menu()
             taxonomy = "\u25B8".join(
                 ["all"]
-                + [step.selected["__name"] for step in self.steps if step.name == "group_menu"]
+                + [step.selected["__name"] for step in self.steps if step.name == "group_menu"],
             )
 
             columns = ["__name", "__taxonomy", "__type"]
@@ -321,7 +366,7 @@ class Action(App):
 
             return Step(
                 name="group_menu",
-                tipe="menu",
+                step_type="menu",
                 value=menu,
                 columns=columns,
                 select_func=self._host_or_group_step,
@@ -332,6 +377,10 @@ class Action(App):
             return self.steps.back_one()
 
     def _build_host_content(self) -> Step:
+        """Build the inventory content for one host.
+
+        :returns: The inventory content for the host
+        """
         host_vars = self._host_vars
         try:
             values = [
@@ -341,7 +390,7 @@ class Action(App):
             ]
             entry = Step(
                 name="host_content",
-                tipe="content",
+                step_type="content",
                 value=values,
                 index=self.steps.current.index,
                 columns=["__name"] + self._show_columns,
@@ -353,11 +402,15 @@ class Action(App):
             return self.steps.back_one()
 
     def _refresh(self) -> None:
-        """rebuild the current step and replace"""
+        """Refresh the current step, removing and replacing it."""
         self.steps.back_one()
         self.steps.append(self.steps.current.select_func())
 
     def _build_host_menu(self) -> Step:
+        """Build the menu of hosts.
+
+        :returns: The hosts menu definition
+        """
         menu = Menu()
         for host in self._host_vars.values():
             host["__type"] = "host"
@@ -366,81 +419,56 @@ class Action(App):
         return Step(
             columns=columns,
             name="host_menu",
-            tipe="menu",
+            step_type="menu",
             value=menu,
             select_func=self._build_host_content,
             show_func=self._refresh,
         )
 
     def _host_or_group_step(self) -> Step:
+        """Build a menu based on the type of the current step.
+
+        :raises TypeError: When the step type is unknown
+        :returns: The group or host menu definition
+        """
         if self.steps.current.selected["__type"] == "group":
             return self._build_group_menu()
         if self.steps.current.selected["__type"] == "host":
             return self._build_host_content()
         raise TypeError("unknown step type")
 
-    def _build_inventory_list(self) -> None:
-
-        self._update_args(
-            [self._name] + shlex.split(self._interaction.action.match.groupdict()["params"] or "")
-        )
-
-        if isinstance(self._args.inventory, list):
-            inventories = self._args.inventory
-            inventories_valid = not self._inventory_error
-        else:
-            inventories = ["", "", ""]
-            inventories_valid = False
-
-        if not inventories_valid:
-            FType = Dict[str, Any]
-            form_dict: FType = {
-                "title": "One or more inventory sources could not be found",
-                "fields": [],
-            }
-            if inventories:
-                for idx, inv in enumerate(inventories):
-                    form_field = {
-                        "name": f"inv_{idx}",
-                        "pre_populate": inv,
-                        "prompt": f"{idx}. Inventory source",
-                        "type": "text_input",
-                        "validator": {"name": "none"},
-                    }
-                    form_dict["fields"].append(form_field)
-            else:
-                form_field = {
-                    "name": "inv_0",
-                    "prompt": "0. Inventory source",
-                    "type": "text_input",
-                    "validator": {"name": "none"},
-                }
-                form_dict["fields"].append(form_field)
-
-            form = dict_to_form(form_dict)
-            self._interaction.ui.show(form)
-
-            if form.cancelled:
-                return
-
-            inventories = [
-                field.value
-                for field in form.fields
-                if hasattr(field, "value") and field.value != ""
-            ]
-            if not inventories:
-                return
-
-        self._inventories = inventories
-        self._set_inventories_mtime()
-        return
-
     def _collect_inventory_details_interactive(
         self,
         kwargs: Dict[str, Any],
     ) -> None:
-        self._runner = InventoryRunner(**kwargs)
-        inventory_output, inventory_err = self._runner.fetch_inventory("list", self._inventories)
+        # pylint: disable=too-many-branches
+        """Use the runner subsystem to collect inventory details for mode interactive.
+
+        :param kwargs: The arguments for the runner call
+        """
+        try:
+            # Extract the playbook dir the user may have provided
+            index = self._args.cmdline.index("--playbook-dir")
+            playbook_dir = self._args.cmdline[index + 1]
+            source = "user provided"
+        # Constants don't have an index, may go past end of list, param not found
+        except (AttributeError, IndexError, ValueError):
+            if isinstance(self._args.playbook, str):
+                # or use the parent of the currently set playbook
+                playbook_dir = str(Path(self._args.playbook).resolve().parent)
+                source = "derived from playbook"
+            else:
+                # or the current working directory
+                playbook_dir = os.getcwd()
+                source = "CWD"
+        self._logger.info("--playbook-directory for inventory from (%s): %s", source, playbook_dir)
+
+        self._runner = AnsibleInventory(**kwargs)
+        inventory_output, inventory_err = self._runner.fetch_inventory(
+            action="list",
+            inventories=self._inventories,
+            playbook_dir=playbook_dir,
+        )
         if inventory_output:
             parts = inventory_output.split("{", 1)
             if inventory_err:
@@ -452,19 +480,32 @@ class Action(App):
                 inventory_output = "{" + parts[1]
             else:
                 inventory_output = ""
-        warn_msg = ["Errors were encountered while gathering the inventory:"]
-        warn_msg += inventory_err.splitlines()
-        self._logger.error(" ".join(warn_msg))
-        if "ERROR!" in inventory_err or "Error" in inventory_err:
-            warning = warning_notification(warn_msg)
-            self._interaction.ui.show(warning)
+        preface = ["Errors were encountered while gathering the inventory:"]
+        notify = ("ERROR!", "Error", "Unable to parse")
+        if any(string in inventory_err for string in notify):
+            if "[WARNING]" in inventory_err:
+                parts = inventory_err.split("[WARNING]")
+                messages = [part.replace("\n", " ").strip() for part in parts if part]
+                present = preface + [f"[WARNING]{message}" for message in messages]
+            else:
+                present = preface + inventory_err.splitlines()
+            for line in present:
+                self._logger.error(line)
+            warning = warning_notification(present)
+            self._interaction.ui.show_form(warning)
         else:
             self._extract_inventory(inventory_output)
 
     def _collect_inventory_details_automated(
         self,
         kwargs: Dict[str, Any],
-    ) -> Tuple[Union[None, str], Union[None, str], Union[None, int]]:
+    ) -> Tuple[Optional[str], Optional[str], Optional[int]]:
+        """Use the runner subsystem to collect inventory details for mode stdout.
+
+        :param kwargs: The arguments for the runner call
+        :raises RuntimeError: When the ``ansible-inventory`` command cannot be found for mode stdout
+        :returns: The output, errors and return code from runner
+        """
         if self._args.execution_environment:
             ansible_inventory_path = "ansible-inventory"
         else:
@@ -485,20 +526,25 @@ class Action(App):
 
         kwargs.update({"cmdline": pass_through_arg, "inventory": self._inventories})
 
-        self._runner = CommandRunner(executable_cmd=ansible_inventory_path, **kwargs)
+        self._runner = Command(executable_cmd=ansible_inventory_path, **kwargs)
         stdout_return = self._runner.run()
         return stdout_return
 
     def _collect_inventory_details(
         self,
-    ) -> Tuple[Union[None, str], Union[None, str], Union[None, int]]:
+    ) -> Tuple[Optional[str], Optional[str], Optional[int]]:
+        """Use the runner subsystem to collect inventory details for either mode.
+
+        :returns: For mode interactive nothing. For mode stdout, the output, errors and return
+            code from runner
+        """
         if isinstance(self._args.set_environment_variable, dict):
-            set_envvars = {**self._args.set_environment_variable}
+            set_env_vars = {**self._args.set_environment_variable}
         else:
-            set_envvars = {}
+            set_env_vars = {}
 
         if self._args.display_color is False:
-            set_envvars["ANSIBLE_NOCOLOR"] = "1"
+            set_env_vars["ANSIBLE_NOCOLOR"] = "1"
 
         kwargs = {
             "container_engine": self._args.container_engine,
@@ -507,7 +553,7 @@ class Action(App):
             "execution_environment": self._args.execution_environment,
             "navigator_mode": self._args.mode,
             "pass_environment_variable": self._args.pass_environment_variable,
-            "set_environment_variable": set_envvars,
+            "set_environment_variable": set_env_vars,
             "private_data_dir": self._args.ansible_runner_artifact_dir,
             "rotate_artifacts": self._args.ansible_runner_rotate_artifacts_count,
             "timeout": self._args.ansible_runner_timeout,
@@ -515,7 +561,7 @@ class Action(App):
 
         if isinstance(self._args.execution_environment_volume_mounts, list):
             kwargs.update(
-                {"container_volume_mounts": self._args.execution_environment_volume_mounts}
+                {"container_volume_mounts": self._args.execution_environment_volume_mounts},
             )
 
         if isinstance(self._args.container_options, list):
@@ -529,6 +575,10 @@ class Action(App):
         return (None, None, None)
 
     def _extract_inventory(self, stdout: str) -> None:
+        """Load and the ``json`` output from the inventory collection process.
+
+        :param stdout: The output from the inventory collection process
+        """
         try:
             self._inventory = json.loads(stdout)
         except json.JSONDecodeError as exc:
