@@ -1,25 +1,23 @@
-""" a text imput field
-"""
+"""A text input field."""
 from dataclasses import dataclass
-
 from typing import Any
 from typing import Callable
+from typing import Optional
 from typing import Union
 
 from .curses_window import Window
 from .form_handler_text import FormHandlerText
-from .sentinals import nonexistent
-from .sentinals import unknown
-from .sentinals import Unknown
+from .sentinels import Unknown
+from .sentinels import nonexistent
+from .sentinels import unknown
 from .validators import FieldValidators
 
 
 @dataclass
 class FieldText:
-
     # pylint: disable=too-many-instance-attributes
-    # pylint: disable=unsubscriptable-object
-    """a text inout field"""
+    """A text input field."""
+
     name: str
     prompt: str
     current_error: str = ""
@@ -29,29 +27,41 @@ class FieldText:
     valid: Union[bool, Unknown] = unknown
     validator: Callable = FieldValidators.none
     value: Any = unknown
-    win: Union[Window, None] = None
+    win: Optional[Window] = None
 
     @property
     def formatted_default(self) -> str:
-        """return the default value"""
+        """Return the default value.
+
+        :returns: Default value or empty string
+        """
         if self.default is nonexistent:
             return ""
         return f" ({self.default})"
 
     @property
     def full_prompt(self) -> str:
-        """the full rpompt includes the default"""
+        """Return the full prompt with the default.
+
+        :returns: Prompt with default text
+        """
         return self.prompt + self.formatted_default
 
     def pre_populate(self, value: str) -> None:
-        """prepopulate this text input
-        with a value, this is different that a default
-        in that it will populate the text input field
+        """Prepopulate this text input with a value.
+
+        This is different from a default
+        in that it will populate the text input field.
+
+        :param value: Item to populate the input field
         """
         self.conditional_validation(str(value))
 
     def validate(self, response: str) -> None:
-        """validate the repsonse"""
+        """Validate the response.
+
+        :param response: Text input response
+        """
         if response == "" and self.default is not nonexistent:
             response = str(self.default)
 
@@ -65,12 +75,15 @@ class FieldText:
             self.value = validation.value
 
     def conditional_validation(self, response: str) -> None:
-        """conditional validation used for tab,
-        only accept the value if it validates, otherwise move along
+        """Conditional validation used for tab.
+
+        Only accept the value if it validates, otherwise move along.
+
+        :param response: Text input response
         """
         if response == "" and self.default is not nonexistent:
             response = str(self.default)
-        # no repsonse or validator is none
+        # no response or validator is none
         if response or getattr(self.validator, "__name__", "").endswith("none"):
             validation = self.validator(text=response)
             if not validation.error_msg:
