@@ -1,10 +1,9 @@
-""" information handler, instant enter
-"""
+"""Information handler, instant enter."""
 
 from curses import ascii as curses_ascii
+from typing import TYPE_CHECKING
 from typing import List
 from typing import Tuple
-from typing import TYPE_CHECKING
 
 from .curses_window import CursesWindow
 
@@ -14,14 +13,23 @@ if TYPE_CHECKING:
 
 
 class FormHandlerInformation(CursesWindow):
-    # pylint: disable=too-few-public-methods
-    """handle form button"""
+    """Handle form button."""
 
     def __init__(self, screen, ui_config):
+        """Initialize the handler for a informational notification.
+
+        :param screen: A curses window
+        :param ui_config: The current user interface configuration
+        """
         super().__init__(ui_config=ui_config)
         self._screen = screen
 
     @staticmethod
     def handle(idx, form_fields: List) -> Tuple["FieldInformation", int]:
-        """handle the information field, immediate return"""
+        """Handle the information field, immediate return.
+
+        :param idx: Index to retrieve specific field
+        :param form_fields: List of fields
+        :returns: Indexed form fields
+        """
         return form_fields[idx], curses_ascii.NL
