@@ -1,21 +1,26 @@
-""" Get one line of text input
-"""
+"""Get one line of text input."""
 
 import curses
-from curses.textpad import Textbox
+
 from curses import ascii as curses_ascii
+from curses.textpad import Textbox
 from typing import Tuple
 
-
+from .curses_defs import CursesLine
 from .curses_defs import CursesLinePart
 from .curses_window import CursesWindow
-from .sentinals import unknown
+from .sentinels import unknown
 
 
 class FormHandlerText(CursesWindow, Textbox):
-    """Get one line of text input"""
+    """Get one line of text input."""
 
     def __init__(self, screen, ui_config):
+        """Initialize the handler for a form text field.
+
+        :param screen: A curses window
+        :param ui_config: The current user interface configuration
+        """
         super().__init__(ui_config=ui_config)
         self.input_line_cache = []
         self.input_line_pointer = 0
@@ -24,16 +29,18 @@ class FormHandlerText(CursesWindow, Textbox):
         self.stripspaces = True
         self._screen = screen
 
-    def _paint_from_line_cache(self) -> None:
-        """put the text from the line cache in the text input window"""
-        clp = CursesLinePart(0, self.input_line_cache[self.input_line_pointer], 0, 0)
-        cline = (clp,)
-        self._add_line(self.win, 0, cline)
+    def _paint_from_line_cache(
+        self,
+    ) -> None:
+        """Put the text from the line cache in the text input window."""
+        line_part = CursesLinePart(0, self.input_line_cache[self.input_line_pointer], 0, 0)
+        self._add_line(self.win, 0, CursesLine((line_part,)))
         self.win.clrtoeol()
 
     def _adjust_line_pointer(self, amount: int) -> None:
-        """increase the curent postion in the
-        line cache
+        """Increase the current position in the line cache.
+
+        :param amount: The number to increase by
         """
         self.input_line_pointer = (self.input_line_pointer + amount) % len(self.input_line_cache)
 
@@ -58,7 +65,7 @@ class FormHandlerText(CursesWindow, Textbox):
                     self._arrowing = True
                 else:
                     self._adjust_line_pointer(1)
-                self._paint_from_line_cache()
+                    self._paint_from_line_cache()
             ret = 1
         elif char in (curses_ascii.DLE, curses.KEY_UP):
             if self.input_line_cache:
@@ -67,22 +74,27 @@ class FormHandlerText(CursesWindow, Textbox):
                     self._arrowing = True
                 else:
                     self._adjust_line_pointer(-1)
-                self._paint_from_line_cache()
+                    self._paint_from_line_cache()
             ret = 1
         elif char == curses_ascii.TAB:
             ret = 0
         else:
-            ret = bool(self.do_command(char))  # type: ignore
+            ret = bool(self.do_command(char))  # type: ignore[func-returns-value]
             self._arrowing = 0
         return ret
 
     def handle(self, idx, form_fields) -> Tuple[str, int]:
-        "Edit in the widget window and collect the results."
+        """Edit in the widget window and collect the results.
+
+        :param idx: Index to retrieve specific field
+        :param form_fields: List of fields
+        :returns: Results from line and char edit
+        """
         form_field = form_fields[idx]
 
         if form_field.response is not unknown:
-            clp = CursesLinePart(0, form_field.response, 0, 0)
-            self._add_line(self.win, 0, tuple([clp]))
+            line_part = CursesLinePart(0, form_field.response, 0, 0)
+            self._add_line(self.win, 0, CursesLine((line_part,)))
         else:
             self.win.move(0, 0)
 
