@@ -1,10 +1,8 @@
-""" working handler, instant 1112065
-utf-8 max = 112064
-"""
+"""Working handler, instant 1112065, utf-8 max = 112064."""
 
+from typing import TYPE_CHECKING
 from typing import List
 from typing import Tuple
-from typing import TYPE_CHECKING
 
 from .curses_window import CursesWindow
 
@@ -14,14 +12,23 @@ if TYPE_CHECKING:
 
 
 class FormHandlerWorking(CursesWindow):
-    # pylint: disable=too-few-public-methods
-    """handle form button"""
+    """Handle form button."""
 
     def __init__(self, screen, ui_config):
+        """Initialize the handler for a form working notification.
+
+        :param screen: A curses window
+        :param ui_config: The current user interface configuration
+        """
         super().__init__(ui_config=ui_config)
         self._screen = screen
 
     @staticmethod
     def handle(idx, form_fields: List) -> Tuple["FieldWorking", int]:
-        """handle the information field, immediate return"""
+        """Handle the information field, immediate return.
+
+        :param idx: Index to retrieve specific field
+        :param form_fields: List of fields from a form
+        :returns: Indexed form fields
+        """
         return form_fields[idx], 112065
