@@ -1,5 +1,4 @@
-""" simple utils for working with forms
-"""
+"""Simple utils for working with forms."""
 import copy
 import shutil
 import textwrap
@@ -8,21 +7,32 @@ from functools import partial
 from typing import Dict
 from typing import List
 
-
+from ansible_navigator.utils.definitions import ExitMessage
+from ansible_navigator.utils.definitions import ExitMessages
+from ansible_navigator.utils.definitions import ExitPrefix
+from ..utils.functions import console_width
+from .colorize import ansi_to_curses
+from .curses_defs import CursesLines
 from .field_checks import FieldChecks
+from .field_curses_information import FieldCursesInformation
 from .field_information import FieldInformation
 from .field_option import FieldOption
 from .field_radio import FieldRadio
 from .field_text import FieldText
 from .field_working import FieldWorking
-from .validators import FieldValidators
 from .form import Form
 from .form import FormType
+from .ui_constants import Color
+from .validators import FieldValidators
 
 
 def dict_to_form(form_data: Dict) -> Form:
     # pylint: disable=too-many-branches
-    """convert a python dict to a form"""
+    """Convert a python dict to a form.
+
+    :param form_data: Form data
+    :returns: Object containing fields from form
+    """
     if form_data.get("type") == "notification":
         form = Form(type=FormType.NOTIFICATION)
     elif form_data.get("type") == "working":
@@ -86,20 +96,24 @@ def dict_to_form(form_data: Dict) -> Form:
 
 
 def form_to_dict(form: Form, key_on_name: bool = False) -> Dict:
-    """populate the original _dict of the form
-    with the results
+    """Populate the original _dict of the form with the results.
+
+    :param form: Holding place for form fields
+    :param key_on_name: Bool used to filter via name
+    :returns: form as type dict
     """
     res = form._dict  # pylint: disable=protected-access
     res["cancelled"] = form.cancelled
     res["submitted"] = form.submitted
-    for idx, field in enumerate(form.fields):
+    for field_idx, field in enumerate(form.fields):
         if isinstance(field, FieldText):
-            res["fields"][idx]["response"] = copy.copy(field.response)
-            res["fields"][idx]["value"] = copy.copy(field.value)
+            res["fields"][field_idx]["response"] = copy.copy(field.response)
+            res["fields"][field_idx]["value"] = copy.copy(field.value)
         elif isinstance(field, (FieldChecks, FieldRadio)):
-            for oidx, option in enumerate(field.options):
-                res["fields"][idx]["options"][oidx]["checked"] = option.checked
-            res["fields"][idx]["checked"] = [
+            for option_idx, option in enumerate(field.options):
+                res_field_options = res["fields"][field_idx]["options"]
+                res_field_options[option_idx]["checked"] = option.checked
+            res["fields"][field_idx]["checked"] = [
                 option.name for option in field.options if option.checked
             ]
 
@@ -117,7 +131,11 @@ def form_to_dict(form: Form, key_on_name: bool = False) -> Dict:
 
 
 def break_long_lines(messages):
-    """break lines such that the form widt !> 80%"""
+    """Break lines such that the form width !> 80%.
+
+    :param messages: Lines of the form
+    :returns: Resulting messages split if needed
+    """
     width = int(shutil.get_terminal_size().columns * 0.8)
     result = []
     for message in messages:
@@ -127,7 +145,11 @@ def break_long_lines(messages):
 
 
 def nonblocking_notification(messages: List[str]) -> Form:
-    """generate a std nonblocking notification"""
+    """Generate a std nonblocking notification.
+
+    :param messages: List of messages to display
+    :returns: Form to display as type dict
+    """
     messages = break_long_lines(messages)
     form = {
         "title": "Working on it...",
@@ -138,8 +160,43 @@ def nonblocking_notification(messages: List[str]) -> Form:
     return dict_to_form(form)
 
 
+def settings_notification(color: bool, messages: List[ExitMessage]) -> Form:
+    """Generate a warning notification for settings errors.
+
+    :param messages: List of messages to display
+    :param color: Bool to reflect if color is transferred or not
+    :returns: The form to display
+    """
+    # Take the initial warning if there is one
+    if messages[0].prefix is ExitPrefix.WARNING:
+        title = messages.pop(0).to_lines(color=False, width=console_width(), with_prefix=True)[0]
+    else:
+        title = "Warning"
+
+    formatted = ExitMessages(messages).to_strings(color=color, width=console_width())
+    formatted_curses = CursesLines(
+        tuple(ansi_to_curses(line) for line in formatted),
+    )
+    form = Form(
+        FormType.NOTIFICATION,
+        title=title,
+        title_color=Color.YELLOW,
+        fields=[
+            FieldCursesInformation(
+                name="settings_warning",
+                information=formatted_curses,
+            ),
+        ],
+    )
+    return form
+
+
 def warning_notification(messages: List[str]) -> Form:
-    """generate a std warning notification"""
+    """Generate a std warning notification.
+
+    :param messages: List of warning messages to be displayed
+    :returns: Form to display as type dict
+    """
     messages = break_long_lines(messages)
     form = {
         "title": "WARNING",
@@ -148,3 +205,35 @@ def warning_notification(messages: List[str]) -> Form:
         "type": "notification",
     }
     return dict_to_form(form)
+
+
+def error_notification(messages: List[str]) -> Form:
+    """Generate a std error notification.
+
+    :param messages: List of error messages to display
+    :returns: Form to display as type dict
+    """
+    messages = break_long_lines(messages)
+    form = {
+        "title": "ERROR",
+        "title_color": 1,
+        "fields": [{"name": "info", "information": messages, "type": "information"}],
+        "type": "notification",
+    }
+    return dict_to_form(form)
+
+
+def success_notification(messages: List[str]) -> Form:
+    """Generate a std success notification.
+
+    :param messages: List of success messages to display
+    :returns: Form to display as type dict
+    """
+    messages = break_long_lines(messages)
+    form = {
+        "title": "SUCCESS",
+        "title_color": 2,
+        "fields": [{"name": "info", "information": messages, "type": "information"}],
+        "type": "notification",
+    }
+    return dict_to_form(form)
